<?php
if(!defined("IN_MYBB"))
{
	die("Direct initialization of this file is not allowed.<br /><br />Please make sure IN_MYBB is defined.");
}

$plugins->add_hook('member_do_register_start', 'stopforumspam_check');

function stopforumspam_info()
{
	global $mybb;
	
	$compat = (substr($mybb->version_code, 0, 2) == "12") ? "1.2.13,1.4.*" : "1213,14*";
	
	return array(
		"name"			=> "Stop Forum Spam",
		"description"	=> "A plugin that integrates with <a href=\"http://stopforumspam.com/\">StopForumSpam</a> to try to stop forum spam.",
		"website"		=> "http://mods.mybboard.net/view/stop-forum-spam",
		"author"		=> "LegosJedi",
		"authorsite"	=> "http://mods.mybboard.net/profile/6391",
		"version"		=> "1.0.0",
		"compatibility" => $compat, // Though compatibility is set for 1.4, that's really just to be 1.4 compliant. This will work with 1.2
		"guid"			=> "0f264cd3b93fe2e437826a358df498b6", // We get it once it's submitted. :)
		"manual"		=> false
	);
}

function stopforumspam_activate()
{
	global $db, $mybb;
	
	stopforumspam_deactivate();
	
	$prefix = (substr($mybb->version_code, 0, 2) == "12") ? TABLE_PREFIX : "";
	
	$query = $db->simple_select($prefix."settinggroups", "COUNT(*) as rows");
	$rows = $db->fetch_field($query, "rows");
	
	$insertarray = array(
		'name' => 'stopforumspam', 
		'title' => 'Stop Forum Spam', 
		'description' => $db->escape_string('Options on how to configure and personalize the "Stop Forum Spam" plugin.'), 
		'disporder' => $rows+1, 
		'isdefault' => 0
	);
	$group['gid'] = $db->insert_query($prefix."settinggroups", $insertarray);
	
	if(substr($mybb->version_code, 0, 2) == "12")
	{
		$group['gid'] = $db->insert_id();
	}
	
	$setting_1 = array(
		'name' => 'sfs_ip',
		'title' => "Stop Forum Spam - IP Addresses?",
		'description' => 'Should we check the IP Address against Stop Forum Spam?',
		'optionscode' => 'yesno',
		'value' => 'no',
		'disporder' => 0,
		'gid' => $group['gid'],
	);
	
	$setting_2 = array(
		'name' => 'sfs_email',
		'title' => "Stop Forum Spam - Email Addresses?",
		'description' => 'Should we check the Email Address against Stop Forum Spam?',
		'optionscode' => 'yesno',
		'value' => 'yes',
		'disporder' => 0,
		'gid' => $group['gid'],
	);
	
	$setting_3 = array(
		'name' => 'sfs_username',
		'title' => "Stop Forum Spam - Username?",
		'description' => 'Should we check the Username against Stop Forum Spam?',
		'optionscode' => 'yesno',
		'value' => 'yes',
		'disporder' => 0,
		'gid' => $group['gid'],
	);
	
	$db->insert_query($prefix."settings", $setting_1);
	$db->insert_query($prefix."settings", $setting_2);
	$db->insert_query($prefix."settings", $setting_3);
	
	rebuild_settings();
}

function stopforumspam_deactivate()
{
	global $db, $mybb;
	
	$prefix = (substr($mybb->version_code, 0, 2) == "12") ? TABLE_PREFIX : "";
	
	$db->delete_query($prefix."settinggroups", "name='stopforumspam' OR title='Stop Forum Spam'");
	$db->delete_query($prefix."settings", "name='sfs_ip'");
	$db->delete_query($prefix."settings", "name='sfs_email'");
	$db->delete_query($prefix."settings", "name='sfs_username'");
	
	rebuild_settings();
}

function stopforumspam_check()
{
	global $session, $mybb;
	
	require_once MYBB_ROOT."inc/class_xml.php";
	
	if($mybb->settings['sfs_ip'] == "yes")
	{
		$contents = fetch_remote_file("http://www.stopforumspam.com/api?ip=".$session->ipaddress);
		if(!$contents)
		{
			
		}
		else
		{
			$parser = new XMLParser($contents);
			$tree = $parser->get_tree();
			
			if($tree['response']['appears']['value'] == "yes")
			{
				// Uh, yeah, there's no point in a separate language file. Just modify this file, and upload it. :)
				error("When checked with <a href=\"http://www.stopforumspam.com/\">StopForumSpam</a>, it appears that, according to your ip (".$session->ipaddress."), you are a known spammer. Sorry, but you can't register. Feel free to email the administrator if you feel this is incorrect.", "Known Spammer");
			}
		}
	}
	
	if($mybb->settings['sfs_email'] == "yes")
	{
		$contents = fetch_remote_file("http://www.stopforumspam.com/api?email=".$mybb->input['email']);
		if(!$contents)
		{
			
		}
		else
		{
			$parser = new XMLParser($contents);
			$tree = $parser->get_tree();
			
			if($tree['response']['appears']['value'] == "yes")
			{
				// Uh, yeah, there's no point in a separate language file. Just modify this file, and upload it. :)
				error("When checked with <a href=\"http://www.stopforumspam.com/\">StopForumSpam</a>, it appears that, according to your inputted email address (".$mybb->input['email']."), you are a known spammer. Sorry, but you can't register. Feel free to email the administrator if you feel this is incorrect.", "Known Spammer");
			}
		}
	}
	
	if($mybb->settings['sfs_username'] == "yes")
	{
		$contents = fetch_remote_file("http://www.stopforumspam.com/api?username=".$mybb->input['username']);
		if(!$contents)
		{
			
		}
		else
		{
			$parser = new XMLParser($contents);
			$tree = $parser->get_tree();
			
			if($tree['response']['appears']['value'] == "yes")
			{
				// Uh, yeah, there's no point in a separate language file. Just modify this file, and upload it. :)
				error("When checked with <a href=\"http://www.stopforumspam.com/\">StopForumSpam</a>, it appears that, according to your inputted username (".$mybb->input['username']."), you are a known spammer. Sorry, but you can't register. Feel free to email the administrator if you feel this is incorrect.", "Known Spammer");
			}	
		}
	}
}

if(!function_exists('rebuild_settings'))
{
	function rebuild_settings()
	{
		return rebuildsettings();
	}
}
?>